package com.ruoyi.web.controller.api;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;

import java.util.List;
import java.util.Arrays;

import com.ruoyi.app.domain.vo.AppMemberVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.ruoyi.common.utils.StringUtils;
import lombok.RequiredArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.app.domain.TbFamilyMember;
import com.ruoyi.app.service.ITbFamilyMemberService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 家族成员
 * 
 * @author Administrator
 * @date 2020-10-08
 */
@Api(value = "家族成员", tags = "家族成员")
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/system/member" )
public class TbFamilyMemberController extends BaseController {

    private final ITbFamilyMemberService iTbFamilyMemberService;

    /**
     * 查询家族成员列表
     */
    @ApiOperation("查询家族成员列表")
    @PreAuthorize("@ss.hasPermi('system:member:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppMemberVo memberVo) {
        startPage();
        List<AppMemberVo> list = iTbFamilyMemberService.selectFamilyMember(memberVo);
        return getDataTable(list);
    }

    /**
     * 导出家族成员列表
     */
    @ApiOperation("导出家族成员列表")
    @PreAuthorize("@ss.hasPermi('system:member:export')" )
    @Log(title = "家族成员" , businessType = BusinessType.EXPORT)
    @GetMapping("/export" )
    public AjaxResult export(TbFamilyMember tbFamilyMember) {
        LambdaQueryWrapper<TbFamilyMember> lqw = new LambdaQueryWrapper<TbFamilyMember>(tbFamilyMember);
        List<TbFamilyMember> list = iTbFamilyMemberService.list(lqw);
        ExcelUtil<TbFamilyMember> util = new ExcelUtil<TbFamilyMember>(TbFamilyMember. class);
        return util.exportExcel(list, "member" );
    }

    /**
     * 获取家族成员详细信息
     */
    @ApiOperation("获取家族成员详细信息")
    @PreAuthorize("@ss.hasPermi('system:member:query')" )
    @GetMapping(value = "/{id}" )
    public AjaxResult getInfo(@PathVariable("id" ) Long id) {
        return AjaxResult.success(iTbFamilyMemberService.getById(id));
    }

    /**
     * 新增家族成员
     */
    @ApiOperation("新增家族成员")
    @PreAuthorize("@ss.hasPermi('system:member:add')" )
    @Log(title = "家族成员" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppMemberVo memberVo) {
        return toAjax(iTbFamilyMemberService.saveOrUpdate(memberVo) ? 1 : 0);
    }

    /**
     * 修改家族成员
     */
    @ApiOperation("修改家族成员")
    @PreAuthorize("@ss.hasPermi('system:member:edit')" )
    @Log(title = "家族成员" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppMemberVo memberVo) {
        return toAjax(iTbFamilyMemberService.saveOrUpdate(memberVo) ? 1 : 0);
    }

    /**
     * 删除家族成员
     */
    @ApiOperation("删除家族成员")
    @PreAuthorize("@ss.hasPermi('system:member:remove')" )
    @Log(title = "家族成员" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}" )
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(iTbFamilyMemberService.removeByIds(Arrays.asList(ids)) ? 1 : 0);
    }
}
